option explicit

' ****************************************************************************
' *** VERSION ****************************************************************
' ****************************************************************************
'
' LaunchViaLabel.vbs
'  v1.00
'  14/Aug/2009
'  by Leo Davidson <leo@ox.compsoc.net> http://www.pretentiousname.com
'  Tested with Windows 7 RTM x64

' ****************************************************************************
' *** PURPOSE ****************************************************************
' ****************************************************************************
' 
' This script runs a command on a particular drive, looking up the drive via
' its label. It can be useful when you want to launch something from a USB
' drive which doesn't always have the same label.
'

' ****************************************************************************
' *** USAGE ******************************************************************
' ****************************************************************************
'
' You should run the script with at least two arguments. The first argument is
' the label of the drive you want to look up. The rest of the arguments are
' the command you want to run.
'
' Any occurrences of "__DRIVE__" in the arguments will be replaced with the
' drive letter (e.g. "X:").
'
'
' Example 1)
'
' If "My USB Stick" is mounted as U: then this:
'
'     LaunchViaLabel.vbs "My USB Stick" __DRIVE__\HelloWorld.exe
'
' Will run this:
'
'     U:\HelloWorld.exe
'
'
' Example 2)
'
' If "LEOCAMERA" is mounted as M: then this:
'
'     LaunchViaLabel.vbs "LEOCAMERA" Explorer.exe __DRIVE__
'
' Will run this:
'
'     Explorer.exe M:
'
' That will launch Explorer showing the M: drive.
'
' (If you want to respect the default file manager instead of launching
' Explorer explicitly, you'd just launch the drive letter by itself and let
' Windows decide what to run. In that case you should set WaitForCommand=False
' below. Otherwise you'll get an error message because the script can only
' wait for commands to complete if they run an executable directly.)


' ****************************************************************************
' *** CONFIG *****************************************************************
' ****************************************************************************
'
' Change WaitForCommand to False if you don't want to script to wait for the
' command to complete.

Dim WaitForCommand
WaitForCommand = True


' ****************************************************************************
' *** MAIN *******************************************************************
' ****************************************************************************

Dim Args
set Args = WScript.Arguments

Dim Shell
Set Shell = CreateObject("WScript.Shell")

Dim WmiCim
Set WmiCim = GetObject("winmgmts:\\.\root\cimv2")

If Args.Count < 2 Then
	WScript.Echo Wscript.ScriptName & ": Run with at least two arguments. See comments at the top of the script for instructions."
	WScript.Quit 1
End If

Dim DriveLabel
DriveLabel = Args(0)

Dim DriveList
Set DriveList = WmiCim.ExecQuery("Select * from Win32_LogicalDisk where VolumeName='" & DriveLabel & "'")

If DriveList.Count = 0 Then
	WScript.Echo Wscript.ScriptName & ": No drive with label """ & DriveLabel & """ could not be found."
	WScript.Quit 1
End If

If DriveList.Count > 1 Then
	WScript.Echo Wscript.ScriptName & ": Multiple drives with label """ & DriveLabel & """ were found."
	WScript.Quit 1
End If

Dim Drive
Dim i
Dim Quote
Dim CmdLine
CmdLine = ""

For i = 1 to Args.Count - 1
	If i > 1 Then
		CmdLine = CmdLine & " "
	End If

	If InStr(Args(i), " ") <> 0 Then
		Quote = """"
	Else
		Quote = ""
	End If
		
	CmdLine = CmdLine & Quote & Args(i) & Quote
Next


For Each Drive In DriveList
	CmdLine = Replace(CmdLine, "__DRIVE__", Drive.Name)
Next

Shell.Run CmdLine, 1, WaitForCommand
